==> ts3-0.7.1.tar.gz: ts3-0.7.1/ts3/__init__.py <==
#!/usr/bin/env python3

# The MIT License (MIT)
#
# Copyright (c) 2013-2016 Benedikt Schmitt <benedikt@benediktschmitt.de>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

"""
This package contains a thread-safe Python API for the:
    * TeamSpeak 3 Server Query
    * TeamSpeak 3 Filetransfer Interface
    * TeamSpeak 3 Query Events
"""


# Data
# ------------------------------------------------
__version__ = "0.7.1"


# Modules
# ------------------------------------------------

# We only import the high-level modules. If the user needs access to the
# low-level modules, he can still import them manually, but I prefer to keep
# the namespace clean.

try:
    import query
    import filetransfer
    import response

    from common import TS3Error
except ImportError:
    from . import query
    from . import filetransfer
    from . import response

    from .common import TS3Error

==> ts3-1.0.0.tar.gz: ts3-1.0.0/ts3/__init__.py <==
#!/usr/bin/env python3

# The MIT License (MIT)
#
# Copyright (c) 2013-2016 Benedikt Schmitt <benedikt@benediktschmitt.de>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

"""
This package contains a Python API for the:
    * TeamSpeak 3 Server Query
    * TeamSpeak 3 Filetransfer Interface
    * TeamSpeak 3 Query Events
"""


# Data
# ------------------------------------------------
__version__ = "1.0.0"


# Modules
# ------------------------------------------------

# We only import the high-level modules. If the user needs access to the
# low-level modules, he can still import them manually, but I prefer to keep
# the namespace clean.

try:
    import query
    import filetransfer
    import response

    from common import TS3Error
except ImportError:
    from . import query
    from . import filetransfer
    from . import response

    from .common import TS3Error
